@@ -1,21 +1,18 @@
 """
 test setting *parts* of objects both positionally and label based
 
-TOD: these should be split among the indexer tests
+TODO: these should be split among the indexer tests
 """
 
-from warnings import catch_warnings
-
 import numpy as np
 import pytest
 
 import pandas as pd
 from pandas import DataFrame, Index, Series, date_range
-from pandas.util import testing as tm
+import pandas._testing as tm
 
 
 class TestPartialSetting:
-    @pytest.mark.filterwarnings("ignore:\\n.ix:FutureWarning")
     def test_partial_setting(self):
 
         # GH2578, allow ix and friends to partially set
@@ -87,32 +84,28 @@ class TestPartialSetting:
         # single dtype frame, overwrite
         expected = DataFrame(dict({"A": [0, 2, 4], "B": [0, 2, 4]}))
         df = df_orig.copy()
-        with catch_warnings(record=True):
-            df.ix[:, "B"] = df.ix[:, "A"]
+        df.loc[:, "B"] = df.loc[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # mixed dtype frame, overwrite
         expected = DataFrame(dict({"A": [0, 2, 4], "B": Series([0, 2, 4])}))
         df = df_orig.copy()
         df["B"] = df["B"].astype(np.float64)
-        with catch_warnings(record=True):
-            df.ix[:, "B"] = df.ix[:, "A"]
+        df.loc[:, "B"] = df.loc[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # single dtype frame, partial setting
         expected = df_orig.copy()
         expected["C"] = df["A"]
         df = df_orig.copy()
-        with catch_warnings(record=True):
-            df.ix[:, "C"] = df.ix[:, "A"]
+        df.loc[:, "C"] = df.loc[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # mixed frame, partial setting
         expected = df_orig.copy()
         expected["C"] = df["A"]
         df = df_orig.copy()
-        with catch_warnings(record=True):
-            df.ix[:, "C"] = df.ix[:, "A"]
+        df.loc[:, "C"] = df.loc[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # GH 8473
@@ -186,17 +179,15 @@ class TestPartialSetting:
 
         # loc equiv to .reindex
         expected = Series([np.nan, 0.2, np.nan], index=[3, 2, 3])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
+        with pytest.raises(KeyError, match="with any missing labels"):
             result = ser.loc[[3, 2, 3]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
 
         result = ser.reindex([3, 2, 3])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         expected = Series([np.nan, 0.2, np.nan, np.nan], index=[3, 2, 3, "x"])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
+        with pytest.raises(KeyError, match="with any missing labels"):
             result = ser.loc[[3, 2, 3, "x"]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
 
         result = ser.reindex([3, 2, 3, "x"])
         tm.assert_series_equal(result, expected, check_index_type=True)
@@ -206,9 +197,8 @@ class TestPartialSetting:
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         expected = Series([0.2, 0.2, np.nan, 0.1], index=[2, 2, "x", 1])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
+        with pytest.raises(KeyError, match="with any missing labels"):
             result = ser.loc[[2, 2, "x", 1]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
 
         result = ser.reindex([2, 2, "x", 1])
         tm.assert_series_equal(result, expected, check_index_type=True)
@@ -222,54 +212,48 @@ class TestPartialSetting:
             ser.loc[[3, 3, 3]]
 
         expected = Series([0.2, 0.2, np.nan], index=[2, 2, 3])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[2, 2, 3]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            ser.loc[[2, 2, 3]]
 
         result = ser.reindex([2, 2, 3])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         s = Series([0.1, 0.2, 0.3], index=[1, 2, 3])
         expected = Series([0.3, np.nan, np.nan], index=[3, 4, 4])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = s.loc[[3, 4, 4]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            s.loc[[3, 4, 4]]
 
         result = s.reindex([3, 4, 4])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         s = Series([0.1, 0.2, 0.3, 0.4], index=[1, 2, 3, 4])
         expected = Series([np.nan, 0.3, 0.3], index=[5, 3, 3])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = s.loc[[5, 3, 3]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            s.loc[[5, 3, 3]]
 
         result = s.reindex([5, 3, 3])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         s = Series([0.1, 0.2, 0.3, 0.4], index=[1, 2, 3, 4])
         expected = Series([np.nan, 0.4, 0.4], index=[5, 4, 4])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = s.loc[[5, 4, 4]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            s.loc[[5, 4, 4]]
 
         result = s.reindex([5, 4, 4])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         s = Series([0.1, 0.2, 0.3, 0.4], index=[4, 5, 6, 7])
         expected = Series([0.4, np.nan, np.nan], index=[7, 2, 2])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = s.loc[[7, 2, 2]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            s.loc[[7, 2, 2]]
 
         result = s.reindex([7, 2, 2])
         tm.assert_series_equal(result, expected, check_index_type=True)
 
         s = Series([0.1, 0.2, 0.3, 0.4], index=[1, 2, 3, 4])
         expected = Series([0.4, np.nan, np.nan], index=[4, 5, 5])
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = s.loc[[4, 5, 5]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            s.loc[[4, 5, 5]]
 
         result = s.reindex([4, 5, 5])
         tm.assert_series_equal(result, expected, check_index_type=True)
@@ -286,28 +270,19 @@ class TestPartialSetting:
         ser = Series([0.1, 0.2], index=idx, name="s")
 
         # loc
-        exp_idx = Index([3, 2, 3], dtype="int64", name="idx")
-        expected = Series([np.nan, 0.2, np.nan], index=exp_idx, name="s")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[3, 2, 3]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            ser.loc[[3, 2, 3]]
 
-        exp_idx = Index([3, 2, 3, "x"], dtype="object", name="idx")
-        expected = Series([np.nan, 0.2, np.nan, np.nan], index=exp_idx, name="s")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[3, 2, 3, "x"]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            ser.loc[[3, 2, 3, "x"]]
 
         exp_idx = Index([2, 2, 1], dtype="int64", name="idx")
         expected = Series([0.2, 0.2, 0.1], index=exp_idx, name="s")
         result = ser.loc[[2, 2, 1]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-        exp_idx = Index([2, 2, "x", 1], dtype="object", name="idx")
-        expected = Series([0.2, 0.2, np.nan, 0.1], index=exp_idx, name="s")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[2, 2, "x", 1]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            ser.loc[[2, 2, "x", 1]]
 
         # raises as nothing in in the index
         msg = (
@@ -317,46 +292,28 @@ class TestPartialSetting:
         with pytest.raises(KeyError, match=msg):
             ser.loc[[3, 3, 3]]
 
-        exp_idx = Index([2, 2, 3], dtype="int64", name="idx")
-        expected = Series([0.2, 0.2, np.nan], index=exp_idx, name="s")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = ser.loc[[2, 2, 3]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            ser.loc[[2, 2, 3]]
 
-        exp_idx = Index([3, 4, 4], dtype="int64", name="idx")
-        expected = Series([0.3, np.nan, np.nan], index=exp_idx, name="s")
         idx = Index([1, 2, 3], dtype="int64", name="idx")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3], index=idx, name="s").loc[[3, 4, 4]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            Series([0.1, 0.2, 0.3], index=idx, name="s").loc[[3, 4, 4]]
 
-        exp_idx = Index([5, 3, 3], dtype="int64", name="idx")
-        expected = Series([np.nan, 0.3, 0.3], index=exp_idx, name="s")
         idx = Index([1, 2, 3, 4], dtype="int64", name="idx")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[5, 3, 3]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[5, 3, 3]]
 
-        exp_idx = Index([5, 4, 4], dtype="int64", name="idx")
-        expected = Series([np.nan, 0.4, 0.4], index=exp_idx, name="s")
         idx = Index([1, 2, 3, 4], dtype="int64", name="idx")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[5, 4, 4]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[5, 4, 4]]
 
-        exp_idx = Index([7, 2, 2], dtype="int64", name="idx")
-        expected = Series([0.4, np.nan, np.nan], index=exp_idx, name="s")
         idx = Index([4, 5, 6, 7], dtype="int64", name="idx")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[7, 2, 2]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[7, 2, 2]]
 
-        exp_idx = Index([4, 5, 5], dtype="int64", name="idx")
-        expected = Series([0.4, np.nan, np.nan], index=exp_idx, name="s")
         idx = Index([1, 2, 3, 4], dtype="int64", name="idx")
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
-            result = Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[4, 5, 5]]
-        tm.assert_series_equal(result, expected, check_index_type=True)
+        with pytest.raises(KeyError, match="with any missing labels"):
+            Series([0.1, 0.2, 0.3, 0.4], index=idx, name="s").loc[[4, 5, 5]]
 
         # iloc
         exp_idx = Index([2, 2, 1, 1], dtype="int64", name="idx")
@@ -364,7 +321,6 @@ class TestPartialSetting:
         result = ser.iloc[[1, 1, 0, 0]]
         tm.assert_series_equal(result, expected, check_index_type=True)
 
-    @pytest.mark.filterwarnings("ignore:\\n.ix")
     def test_partial_set_invalid(self):
 
         # GH 4940
@@ -375,26 +331,15 @@ class TestPartialSetting:
 
         # don't allow not string inserts
         with pytest.raises(TypeError):
-            with catch_warnings(record=True):
-                df.loc[100.0, :] = df.ix[0]
+            df.loc[100.0, :] = df.iloc[0]
 
         with pytest.raises(TypeError):
-            with catch_warnings(record=True):
-                df.loc[100, :] = df.ix[0]
-
-        with pytest.raises(TypeError):
-            with catch_warnings(record=True):
-                df.ix[100.0, :] = df.ix[0]
-
-        with pytest.raises(ValueError):
-            with catch_warnings(record=True):
-                df.ix[100, :] = df.ix[0]
+            df.loc[100, :] = df.iloc[0]
 
         # allow object conversion here
         df = orig.copy()
-        with catch_warnings(record=True):
-            df.loc["a", :] = df.ix[0]
-            exp = orig.append(Series(df.ix[0], name="a"))
+        df.loc["a", :] = df.iloc[0]
+        exp = orig.append(Series(df.iloc[0], name="a"))
         tm.assert_frame_equal(df, exp)
         tm.assert_index_equal(df.index, Index(orig.index.tolist() + ["a"]))
         assert df.index.dtype == "object"
@@ -404,19 +349,19 @@ class TestPartialSetting:
         # GH5226
 
         # partially set with an empty object series
-        s = Series()
+        s = Series(dtype=object)
         s.loc[1] = 1
         tm.assert_series_equal(s, Series([1], index=[1]))
         s.loc[3] = 3
         tm.assert_series_equal(s, Series([1, 3], index=[1, 3]))
 
-        s = Series()
+        s = Series(dtype=object)
         s.loc[1] = 1.0
         tm.assert_series_equal(s, Series([1.0], index=[1]))
         s.loc[3] = 3.0
         tm.assert_series_equal(s, Series([1.0, 3.0], index=[1, 3]))
 
-        s = Series()
+        s = Series(dtype=object)
         s.loc["foo"] = 1
         tm.assert_series_equal(s, Series([1], index=["foo"]))
         s.loc["bar"] = 3
@@ -442,10 +387,10 @@ class TestPartialSetting:
         # these work as they don't really change
         # anything but the index
         # GH5632
-        expected = DataFrame(columns=["foo"], index=Index([], dtype="int64"))
+        expected = DataFrame(columns=["foo"], index=Index([], dtype="object"))
 
         def f():
-            df = DataFrame()
+            df = DataFrame(index=Index([], dtype="object"))
             df["foo"] = Series([], dtype="object")
             return df
 
@@ -469,22 +414,21 @@ class TestPartialSetting:
         expected["foo"] = expected["foo"].astype("float64")
 
         def f():
-            df = DataFrame()
+            df = DataFrame(index=Index([], dtype="int64"))
             df["foo"] = []
             return df
 
         tm.assert_frame_equal(f(), expected)
 
         def f():
-            df = DataFrame()
+            df = DataFrame(index=Index([], dtype="int64"))
             df["foo"] = Series(np.arange(len(df)), dtype="float64")
             return df
 
         tm.assert_frame_equal(f(), expected)
 
         def f():
-            df = DataFrame()
-            tm.assert_index_equal(df.index, Index([], dtype="object"))
+            df = DataFrame(index=Index([], dtype="int64"))
             df["foo"] = range(len(df))
             return df
 
@@ -549,11 +493,11 @@ class TestPartialSetting:
     def test_partial_set_empty_frame_set_series(self):
         # GH 5756
         # setting with empty Series
-        df = DataFrame(Series())
-        tm.assert_frame_equal(df, DataFrame({0: Series()}))
+        df = DataFrame(Series(dtype=object))
+        tm.assert_frame_equal(df, DataFrame({0: Series(dtype=object)}))
 
-        df = DataFrame(Series(name="foo"))
-        tm.assert_frame_equal(df, DataFrame({"foo": Series()}))
+        df = DataFrame(Series(name="foo", dtype=object))
+        tm.assert_frame_equal(df, DataFrame({"foo": Series(dtype=object)}))
 
     def test_partial_set_empty_frame_empty_copy_assignment(self):
         # GH 5932
